# Supports Organizer.rb
=begin rdoc
= Select Outer Edges
Copyright 2009, Chris Fullmer
All Rights Reserved

== Disclaimer
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

== License
This software is so simple, I'm sure I can't license or copyright it.  Copy and distribute as you see fit.  But if you can't figure out how to write this on your own and you just copy and paste most of it, please give me credit for what you've copied and pasted.

== Information
Author:: Chris Fullmer
Organization:: www.ChrisFullmer.com and distributed on www.sketchucation.com
Name:: Select Outer Edges
Version:: v1.0
SU Version:: Developed on SU 7, should be compatible with 6 and 5 at least.
Date:: June 30, 2009
Description:: This script selects the outer edges of a selection of faces and edges.
Usage:: Run the script from Plugins>Loose Geometry to Groups.  If the user has geometry selected, it will work the selection.  If nothing is slected, it will work with all loose geometry.  It will not group components or existing groups.  It makes a new group for all connected geometry.  So if there are 20 separate boxes, it will make 20 separate groups - 1 for each box.  I use this to quickly group large amounts of quickly made 3d buildings over bery large areas of land.  This way I do not have so much loose geometry floating around.
History::
1.0:: 2009-06-30
   * First release, as a request from John Clements.  
=end


require 'sketchup.rb'

module Clf_select_outer_edges

	def Clf_select_outer_edges.main
	
		model = Sketchup.active_model
		ents = model.entities.to_a.length
		sel = model.selection.to_a
		model.selection.clear
		edges = []
		
		sel.each do |e|
			edges << e if e.is_a? Sketchup::Edge
		end
		edges.each do |e|
			model.selection.add(e) if e.faces.length == 1
		end
		
	end #method

end #module


#----------Menu system----------
if( $submenu )
	organizer = $submenu 
	if !file_loaded?(__FILE__) then
		organizer.add_item("Select Outer Edges") { Clf_select_outer_edges.main  }
	end
else
	if !file_loaded?('clf_menu_loader') then
		$clf_tools_menu = UI.menu("Plugins").add_submenu("Chris Fullmer Tools")
	end
	if !file_loaded?(__FILE__) then
		$clf_tools_menu.add_item("Select Outer Edges") { Clf_select_outer_edges.main  }
	end
end

file_loaded('clf_menu_loader')
file_loaded(__FILE__)